<?php
require_once 'includes/access.php';
require_once 'includes/util.php';

const ACCOUNTING_FILE = '/root/dp18/accounting.xml';
const COUNTERS_FILE   = '/root/dp18/counters.xml';

const INCOME_INDICATORS = [
    'banknotes' => 'Banconote',
    'coins' => 'Monete',
    'coin-box' => 'Cashbox monete',
    'cash-income' => 'Incasso contante',
    'cashless-income' => 'Incasso cashless',
    'pos-income' => 'Incasso POS',
    'extra-income' => 'Credito dovuto'
];
const EXPENDITURE_INDICATORS = [
    'change-delivered' => 'Totale resti',
    'recharges' => 'Ricariche'
];
const COIN_COUNTER_INDICATORS = [ 5, 10, 20, 50, 100, 200 ];
const BILL_COUNTER_INDICATORS = [ 500, 1000, 2000, 5000 ];

function indicator_string($val) {
    return ($val < 500 ? 'Monete' : 'Banconote') . ' ' . money_str($val);
}

$accounting = new DOMDocument();
$accounting->load(ACCOUNTING_FILE);

$counters = new DOMDocument();
$counters->load(COUNTERS_FILE);

function make_section_header($name) {
?>
<h3>
    <?= $name ?>
    <a class="hidden-xs btn btn-default" href="#summary-start">
        <span class="glyphicon glyphicon-chevron-up"></span> Torna all'inizio
    </a>
    <a class="visible-xs-inline-block" href="#summary-start"><span class="glyphicon glyphicon-circle-arrow-up"></span></a>
</h3>
<?php
}

function make_accounting_row($dom, $indicator, $header) {
    echo '<tr><th>' . $header . '</th>';
    $q = new DOMXPath($dom);
    foreach ($q->query("//$indicator") as $elem) {
        echo '<td>' . money_str($elem->textContent) . '</td>';
    }
}

function make_accounting_table($dom) {
?>
<table class="table table-striped table-condensed">
    <thead>
        <tr>
            <th>Indicatore</th>
            <th>Totale</th>
            <th>Parziale</th>
            <th>Log</th>
        </tr>
    </thead>
    <tbody>
        <?php
        foreach (INCOME_INDICATORS as $indicator => $header) {
            make_accounting_row($dom, $indicator, $header);
        }
        echo '<tr><td colspan="4"></td></tr>';
        foreach (EXPENDITURE_INDICATORS as $indicator => $header) {
            make_accounting_row($dom, $indicator, $header);
        }
        ?>
    </tbody>
</table>
<?php
}

function make_counter_row($dom, $val) {
    echo '<tr><th>' . indicator_string($val) . '</th>';    
    $q = new DOMXPath($dom);
    foreach ($q->query("//currency[@value=\"$val\"]") as $elem) {
        echo '<td>' . $elem->textContent . '</td>';
    }
}

function make_hopper_row($dom, $id) {
    echo "<tr><th>Monete hopper $id</th>";  
    foreach ($q->query("//hopper[@id=\"$id\"]") as $elem) {
        echo '<td>' . $elem->textContent . '</td>';
    }
}
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <title>Contabilità</title>
        <style type="text/css">
            table.currency td { text-align: right; }
        </style>
    </head>
    <body>
        <?php include 'templates/navbar.php' ?>
        <div class="container">
            <div id="summary-start" class="page-header"><h1>Contabilità</h1></div>
            <nav class="navbar">
                <ul class="nav nav-pills nav-justified">
                    <li><a href="#income">Movimenti</a></li>
                    <li><a href="#money">Denaro inserito</a></li>
                    <li><a href="#products">Prodotti venduti</a></li>
                    <li><a href="#hoppers">Hopper</a></li>
                </ul>
            </nav>
            <div class="row">
                <section id="income" class="col-sm-6">
                    <?php make_section_header('Movimenti') ?>
                    <?php make_accounting_table($accounting) ?>
                    <section id="hoppers">
                        <?php make_section_header('Erogazioni hopper') ?>
                        
                    </section>
                </section>
                <section id="money" class="col-sm-6">
                    <?php make_section_header('Denaro inserito') ?>
                    <table class="table table-striped table-condensed">
                        <thead>
                            <tr>
                                <th>Indicatore</th>
                                <th>Totale</th>
                                <th>Parziale</th>
                                <th>Log</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            foreach (BILL_COUNTER_INDICATORS as $val) {
                                make_counter_row($counters, $val);
                            }
                            echo '<tr><td colspan="4"></td></tr>';
                            foreach (COIN_COUNTER_INDICATORS as $val) {
                                make_counter_row($counters, $val);
                            }
                            ?>
                        </tbody>
                    </table>
                </section>
            </div>
            <section id="products">
                <?php make_section_header('Contatori motor dispenser') ?>
                <table class="table table-striped table-condensed">
                    <thead>
                        <tr>
                            <th>Selezione</th>
                            <th>Totale</th>
                            <th>Parziale</th>
                            <th>Log</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $q = new DOMXPath($accounting);
                        for ($i = 0; $i < 18; ++$i) {
                            $sel = $i + 1;
                            echo "<tr><td>$sel</td>";
                            foreach ($q->query("//dispenser[@index=\"$i\"]/@count") as $elem) {
                                echo "<td>{$elem->textContent}</td>";
                            }
                            echo '</tr>';
                        }
                        ?>
                    </tbody>
                </table>
            </section>
        </div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>