<?php
require_once 'includes/access.php';
require_once 'includes/util.php';

const ARCHIVE_DIR = '/root/dp18/archive';
const INCOME_INDICATORS = [
    'IncomeCash' => 'Incasso contante',
    'CashBox' => 'Cashbox monete',
    'IncomeUserCard' => 'Incasso cashless',
    'IncomeCreditCard' => 'Incasso POS',
    'IncomeExtra' => 'Credito dovuto'
];
const EXPENDITURE_INDICATORS = [
    'Return' => 'Totale resti',
    'RevalueUserCard' => 'Ricariche'
];
const COUNTERS_TR = [
    'Bill' => 'Banconote',
    'Coin' => 'Monete'
];

function make_section_header($name) {
?>
<h3>
    <?= $name ?>
    <a class="hidden-xs btn btn-default" href="#summary-start">
        <span class="glyphicon glyphicon-chevron-up"></span> Torna all'inizio
    </a>
    <a class="visible-xs-inline-block" href="#summary-start"><span class="glyphicon glyphicon-circle-arrow-up"></span></a>
</h3>
<?php
}

function make_accounting_row($dom, $indicator, $header) {
    echo '<tr><th>' . $header . '</th>';
    foreach ($dom->{$indicator} as $elem) {
        echo '<td>' . money_str($elem->textContent) . '</td>';
    }
}

function make_accounting_table($dom) {
?>
<table class="table table-striped table-condensed">
    <thead>
        <tr>
            <th>Indicatore</th>
            <th>Totale</th>
        </tr>
    </thead>
    <tbody>
        <?php
        foreach (INCOME_INDICATORS as $indicator => $header) {
            make_accounting_row($dom, $indicator, $header);
        }
        echo '<tr><td colspan="4"></td></tr>';
        foreach (EXPENDITURE_INDICATORS as $indicator => $header) {
            make_accounting_row($dom, $indicator, $header);
        }
        ?>
    </tbody>
</table>
<?php
}

function make_counter_row($elem) {
    echo '<tr><th>' . get_or_else(COUNTERS_TR[$elem->getName()], 'Sconosciuto') . '</th>';
    $val = money_str($elem['Value']);
    echo "<td>$val</td><td>{$elem['Count']}</td></tr>";
}

function make_hopper_table($dom) {
?>
<table class="table table-striped table-condensed">
    <thead>
        <tr>
            <th>#</th>
            <th>Valore</th>
            <th>Conteggio monete</th>
        </tr>
    </thead>
    <tbody>
        <?php
        foreach ($dom->Hopper as $hopper) {
            echo "<tr><th>{$hopper['id']}</th><td>{$hopper['Value']}</td><td>{$hopper['Count']}</td></tr>";  
        }
        ?>
    </tbody>
</table>
<?php
}

$dateAndFile = [];
foreach (glob(ARCHIVE_DIR . '/DP18Data*.xml', GLOB_NOSORT) as $filename) {
    $item = basename($filename);
    $matches = [];
    preg_match('/(\d{4})(\d{2})(\d{2})_(\d{2})(\d{2})(\d{2})/', $item, $matches);
    $dateString = "{$matches[1]}/{$matches[2]}/{$matches[3]} {$matches[4]}:{$matches[5]}:{$matches[6]}";
    $dateAndFile[$dateString] = $filename;
}
if (!empty($dateAndFile)) {
    krsort($dateAndFile);
    reset($dateAndFile);
    $defaultVal = key($dateAndFile);
    $selected = filter_input(INPUT_GET, 'date', FILTER_SANITIZE_STRING, [ 'options' => [ 'default' => $defaultVal ] ]);
    $selectedFile = $dateAndFile[$selected];
    $doc = simplexml_load_file($selectedFile);
    
    if (isset($_GET['export']) && file_exists($selectedFile)) {
        make_download_headers($selectedFile);
        exit;
    } else if (isset($_GET['raw']) && file_exists($selectedFile)) {
        make_raw_headers($selectedFile);
        exit;
    }
}
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <title>Riepiloghi</title>
    </head>
    <body>
        <?php include 'templates/navbar.php' ?>
        <div class="container">
            <div class="page-header">
                <h1>
                    <a title="Torna all'archivio" href="/archive.php"><span class="glyphicon glyphicon-circle-arrow-left"></span></a> Riepiloghi
                </h1>
            </div>
            <div class="list-group col-sm-4">
                <?php
                foreach ($dateAndFile as $d => $f) {
                    $activeClass = $d === $selected ? 'active' : '';
                    $query = http_build_query([ 'date' => $d ]);
                    echo "<a class=\"list-group-item $activeClass\" href=\"?$query#summary-start\">$d</a>";
                }
                ?>
            </div>
            <div id="summary-start" class="col-sm-8">
                <h2>
                    <a title="Esporta" href="?<?= http_build_query([ 'date' => $selected, 'export' => '' ])?>"><span class="glyphicon glyphicon-download"></span></a>
                    <a title="Visualizza originale" href="?<?= http_build_query([ 'date' => $selected, 'raw' => '' ])?>"><span class="glyphicon glyphicon-file"></span></a>
                    Riepilogo del <?= $selected ?> <small>Seriale: <?= $doc['SerialNumber'] ?></small>
                </h2>
                <nav class="navbar">
                    <ul class="nav nav-pills nav-justified">
                        <li><a href="#income">Movimenti</a></li>
                        <li><a href="#money">Denaro inserito</a></li>
                        <li><a href="#hoppers">Hopper</a></li>
                        <li><a href="#products">Prodotti venduti</a></li>
                        <li><a href="#versions">Versioni dispositivi</a></li>
                    </ul>
                </nav>
                <div class="row">
                    <section id="income" class="col-sm-6">
                        <?php make_section_header('Movimenti') ?>
                        <?php make_accounting_table($doc) ?>
                        <section id="hoppers">
                            <?php make_section_header('Erogazioni hopper') ?>
                            <?php make_hopper_table($doc) ?>
                        </section>
                    </section>
                    <section id="money" class="col-sm-6">
                        <?php make_section_header('Denaro inserito') ?>
                        <table class="table table-striped table-condensed">
                            <thead>
                                <tr>
                                    <th>Tipo</th>
                                    <th>Valore</th>
                                    <th>Conteggio</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                foreach ($doc->Bill as $bill) {
                                    make_counter_row($bill);
                                }
                                echo '<tr><td colspan="4"></td></tr>';
                                foreach ($doc->Coin as $coin) {
                                    make_counter_row($coin);
                                }
                                ?>
                            </tbody>
                        </table>
                    </section>
                </div>
                <section id="products">
                    <?php make_section_header('Prodotti venduti') ?>
                    <table class="table table-condensed table-striped">
                        <thead>
                            <tr><th>Selezione</th><th>Incasso</th><th>Quantità</th></tr>
                        </thead>
                        <tbody>
                            <?php
                            foreach ($doc->Product as $p) {
                                $amount = money_str($p['Amount']);
                                echo "<tr><th>{$p['id']}</th><td>$amount</td><td>{$p['Count']}</td></tr>";
                            }
                            ?>
                        </tbody>
                    </table>
                </section>
                <section id="versions">
                    <?php make_section_header('Versioni dispositivi') ?>
                    <table class="table table-condensed table-striped">
                        <thead>
                            <tr><th>Dispositivo</th><th>Versione</th></tr>
                        </thead>
                        <tbody>
                        <?php
                        function get_version($versionString) {
                            $separator = strpos($versionString, ':');
                            return $separator === false ? '' : trim(substr($versionString, $separator + 1));
                        }
                        
                        foreach ($doc->Versions->Version as $ver) {
                            $versionStr = get_version($ver['descr']);
                            $txt = strlen($versionStr) == 0 ? 'Sconosciuta' : $versionStr;
                            $rowClass = empty($versionStr) ? 'danger' : 'success';
                            echo "<tr class=\"$rowClass\"><th>{$ver['device']}</th><td>$txt</td></tr>";
                        }
                        ?>
                        </tbody>
                    </table>
                </section>
                <a class="btn btn-default" href="#summary-start" style="margin-bottom: 1rem">
                    <span class="glyphicon glyphicon-chevron-up"></span> Torna all'inizio
                </a>
            </div>
        </div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>
