<?php
const DEVICE_INFO = '/tmp/dp18-device-info.xml';
const QUESTION_MARK = '<span class="glyphicon glyphicon-question-sign"></span>';
                            
function tabulate_versions($from, $to) {
?>
<div class="col-sm-6">
    <table class="table table-condensed">
        <tbody>
        <?php
        for ($i = $from; $i < $to; ++$i) {
            echo "<tr id=\"$i\" class=\"danger\"><th>???</th><td>Sconosciuta</td></tr>";
        }
        ?>
        </tbody>
    </table>
</div>
<?php
}

function render_state($header, $name) {
    echo "<tr><th>$header</th><td id=\"$name\">" . QUESTION_MARK . '</td></tr>';
}

function render_hopper_state($name, $id) {
    $coins = $id . 'Coins';
    echo "<tr><th>$name</th><td id=\"$id\">" . QUESTION_MARK . "</td><td id=\"$coins\">" . QUESTION_MARK . '</td></tr>';
}
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <title>Monitoraggio periferiche</title>
        <script>            
            function safeForEach(obj, callback) {
                if (obj !== undefined)
                    $.each(obj, callback)
            }
            
            $(function() {
                var intervalId = setInterval(function() {
                    $.ajax({
                        method: 'GET',
                        url: '/includes/get_device_status.php',
                        dataType: 'json',
                        timeout: 2500,
                        success: function (data) {
                            $('#timestamp').text(data.timestamp)
                            
                            // Stato dei dispositivi non motori
                            safeForEach(data.state, function(name, val) {
                                if (name.indexOf('Motor') !== 0) { // se il nome della variabile di stato non comincia con 'Motor' 
                                    var value = (name !== 'OutOfPaper') ? val === 1 : val === 0
                                    $('#' + name).html(value ? '<span class="label label-success"><span class="glyphicon glyphicon-ok"></span></span>' :
                                                               '<span class="label label-danger"><span class="glyphicon glyphicon-remove"></span></span>')
                                }
                            })
                                                        
                            // Numero di motor dispenser presenti
                            var actives = 0
                            safeForEach(data.state, function(key, value) {
                                if (key.indexOf('Motor') === 0) // inizia con 'Motor'
                                    actives += parseInt(value)
                            })
                            var motorAlert = actives !== 18
                            $('#motors .badge').text(actives + ' / 18')
                                                        
                            // Versioni
                            var index = 0
                            var rows = $('#versions tr')
                            safeForEach(data.versions, function(key, value) {
                                if (index < rows.length) {
                                    $row = $(rows[index++])
                                    $row.find('th').text(key).end().find('td').text(value)
                                    $row.toggleClass('danger', value.length === 0)
                                }
                            })
                        },
                        error: function(xhr, status, errorStr) {
                            clearInterval(intervalId);
                            $('#status-error').show()
                        }
                    })
                }, 3000);
            })
        </script>
    </head>
    <body>
        <?php include 'templates/navbar.php' ?>
        <div class="container">
            <div class="page-header">
                <h1>Monitoraggio periferiche</h1><small>Ultima modifica <strong id="timestamp">???</strong></small>
            </div>
            <h2 id="status-error" class="text-danger" style="display: none">Attenzione: funzione non disponibile</h2>
            <section>
                <h2>Stato dispositivi</h2>
                <div class="row">
                    <div class="col-sm-6">
                        <table class="table table-condensed">
                            <tbody>
                                <?php render_state('MH430 resettata', 'BoardReset') ?>
                                <?php render_state('Coin acceptor', 'CoinAcceptor') ?>
                                <?php render_state('Rendiresto', 'CoinChanger') ?>
                                <?php render_state('Bill validator', 'BillValidator') ?>
                                <?php render_state('User cashless', 'Cashless') ?>
                                <?php render_state('POS', 'Pos') ?>
                                <?php render_state('Stampante', 'Printer') ?>
                                <?php render_state('Resto disponibile', 'CanGiveChange') ?>
                                <?php render_state('Carta scontrino disponibile', 'OutOfPaper') ?>
                                <tr id="motors"><th>Motor dispenser</th><td><span class="badge">??? / 18</span></td></tr>
                            </tbody>
                        </table>
                    </div>
                    <div class="col-sm-6">
                        <table class="table table-condensed">
                            <thead>
                                <tr><th></th><th>Presenza</th><th>Monete</th></tr>
                            </thead>
                            <tbody>
                                <?php render_hopper_state('Hopper 1', 'Hopper1') ?>
                                <?php render_hopper_state('Hopper 2', 'Hopper2') ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </section>
            <section>
                <h2>Versioni dispositivi</h2>
                <div  id="versions" class="row">
                    <?php
                    tabulate_versions(0, 14);
                    tabulate_versions(14, 28);
                    ?>
                </div>
            </section>
        </div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>
