<?php
require_once __DIR__ . '/util.php';

const IP_PATTERN = '\d{1,3}(\.\d{1,3}){3}';

function set_if_none(&$var, $value) {
    if (!isset($var)) {
        $var = $value;
    }
}

function glyphicon($name) {
    return '<span class="glyphicon glyphicon-' . $name . '"></span>';
}

function form_input_name($section, $key) {
    return $section . '[' . $key .']';
}

function string_value($settings, $section, $key) {
    return isset($settings[$section][$key]) ? "value=\"{$settings[$section][$key]}\"" : '';
}

function __make_input_element($settings, $section, $key, $title, $attributes) {
    $attributes['name'] = form_input_name($section, $key);
    $attributes['value'] = get_or_else($settings[$section][$key]);
    set_if_none($attributes['type'], 'text');
    set_if_none($attributes['class'], 'form-control');
    set_if_none($attributes['placeholder'], $title);
    
    echo '<input';
    foreach ($attributes as $attr => $value) {
        echo "\n$attr=\"" . htmlspecialchars($value) . '"';
    }
    echo '/>';
}

function make_bootstrap_input($title, $settings, $section, $key, $attributes = [], $options = []) {
    $labelCol = get_or_else($options['col'], 4);
?>
<div class="form-group">
    <label class="col-sm-<?= $labelCol ?> control-label"><?= $title ?></label>
    <div class="col-sm-<?= 12 - $labelCol ?>">
        <?php
        if (isset($options['addon'])) {
            echo '<div class="input-group">';
        }
        __make_input_element($settings, $section, $key, $title, $attributes);
        if (isset($options['addon'])) {
            echo '<span class="input-group-addon">';
            echo $options['addon'];
            echo '</span></div>';
        }
        if (isset($options['help'])) {
            echo '<span class="help-block">' . $options['help'] . '</span>';
        }
        ?>
    </div>
</div>
<?php
}

function make_bootstrap_input_element($settings, $section, $key, $attributes = [], $options = []) {
    __make_input_element($settings, $section, $key, get_or_else($attributes['title']), $attributes);
    if (isset($options['addon'])) {
        echo '<span class="input-group-addon">';
        echo $options['addon'];
        echo '</span>';
    }
    if (isset($options['help'])) {
        echo '<span class="help-block">' . $options['help'] . '</span>';
    }
}

function make_bootstrap_combo($title, $settings, $section, $key, $options) {
    $value = get_or_else($settings[$section][$key]);
    $inputName = form_input_name($section, $key);
?>
<div class="form-group">
    <label class="col-xs-4 col-sm-4 control-label"><?= $title ?></label>
    <div class="col-xs-8 col-sm-8">
        <select class="form-control" name="<?= $inputName ?>" autocomplete="off">
            <?php
            foreach ($options as $val => $repr) {
                $isSelected = $value == $val ? 'selected' : '';
            ?>
                <option value="<?= $val ?>" <?= $isSelected ?>><?= $repr ?></option>
            <?php } ?>
        </select>
    </div>
</div>
<?php
}

function make_bootstrap_checkbox($title, $settings, $section, $key, $options = []) {
    $inputName = form_input_name($section, $key);
    $isChecked = filter_var($settings[$section][$key], FILTER_VALIDATE_BOOLEAN) ? 'checked' : '';
    $falseValue = get_or_else($options['false'], 'false');
    $trueValue = get_or_else($options['true'], 'true');
?>
<label>
    <input type="hidden" name ="<?= $inputName ?>" value="<?= $falseValue ?>"/>
    <input type="checkbox" name="<?= $inputName ?>" autocomplete="off" value="<?= $trueValue ?>" <?= $isChecked ?>/><?= $title ?>
</label>
<?php
}

function make_bootstrap_form_input($attributes = [], $options = [], $value = '') {
    $attributes['value'] = $value;
    set_if_none($attributes['type'], 'text');
    set_if_none($attributes['class'], 'form-control');
    set_if_none($attributes['placeholder'], get_or_else($attributes['title']));
    
    echo '<input';
    foreach ($attributes as $attr => $value) {
        echo "\n$attr=\"" . htmlspecialchars($value) . '"';
    }
    echo '/>';
    if (isset($options['addon'])) {
        echo '<span class="input-group-addon">';
        echo $options['addon'];
        echo '</span>';
    }
    if (isset($options['help'])) {
        echo '<span class="help-block">' . $options['help'] . '</span>';
    }
}