<?php
function edit_link($prod) {
    if ($prod->isDeleted()) {
        return '#';
    } else {
        return 'user_product_form.php?' . htmlentities(http_build_query(['id' => $prod->full_id ]));
    }
}
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <title>Impostazione prezzi</title>
        <style type="text/css">
            div.product {
                padding-top: 2px;
                padding-bottom: 2px;
                border-bottom: 1px solid #CCC;
                margin-bottom: 3px;
            }
            div.product:hover {
                background-image: linear-gradient(to bottom, #FFF 0px, #E0E0E0 100%);
            }
            table.prices td {
                padding: 3px;
            }
        </style>
    </head>
    <body>
        <?php include 'templates/navbar.php' ?>
        <div class="container">
            <div class="page-header"><h1>Prodotti personalizzati</h1></div>
            <?php include 'includes/pending_changes_template.php' ?>
            <?php make_toolbar() ?>
            <?php foreach ($products as $id => $prod) {
                if ($prod->catalogue_id() === 'user') {
            ?>
                <div class="row product <?= $prod->isDeleted() ? 'bg-warning' : '' ?>">
                    <div class="col-xs-2 col-sm-2">
                        <a href="<?= edit_link($prod) ?>">
                            <img src="<?= get_thumbnail_url($prod) ?>" class="center-block" style="width: 85px; height: 140px"/>
                        </a>
                    </div>
                    <div class="col-xs-10 col-sm-10">
                        <h4>
                            <a href="<?= edit_link($prod) ?>">
                                <?= $prod->name ?>
                                <span class="small"><?= $prod->product_id() ?></span>
                            </a>
                            <?php if (!product_has_thumbnail($prod)) { ?>
                                <span class="label label-danger">No Miniatura</span>
                            <?php } ?>
                            <?php if (!product_has_image($prod)) { ?>
                                <span class="label label-danger">No Immagine</span>
                            <?php } ?>
                        </h4>
                        <div class="row">
                            <?php if ($prod->isDeleted()) { ?>
                                <a
                                    href="includes/undelete_product.php?<?= htmlentities(http_build_query([
                                        'id' => $prod->full_id,
                                        'redir' => '/user_products.php'
                                    ])) ?>"
                                    class="btn btn-warning">
                                    <span class="glyphicon glyphicon-open"></span> Ripristina prodotto rimosso
                                </a>
                            <?php } else { ?>
                                <table class="col-xs-5 col-sm-3 prices">
                                    <tr>
                                        <td class="small text-danger text-right">Prezzo intero</td>
                                        <td class="text-right"><strong><?= money_str($prod->prices[0]) ?></strong></td>
                                    </tr>
                                    <tr>
                                        <td class="small text-danger text-right">Prezzo scontato</td>
                                        <td class="text-right"><strong><?= money_str($prod->prices[1]) ?></strong></td>
                                    </tr>
                                    <tr>
                                        <td colspan="2" class="text-center">
                                            <a
                                                href="includes/delete_product.php?<?= htmlentities(http_build_query([
                                                    'id' => $prod->full_id,
                                                    'redir' => '/user_products.php'
                                                ])) ?>"
                                                class="btn btn-danger">
                                                <span class="glyphicon glyphicon-remove"></span> Rimuovi
                                            </a>
                                        </td>
                                    </tr>
                                </table>
                                <div class="col-xs-offset-1 col-xs-6 col-sm-offset-1 col-sm-8 text-justify"><strong>Descrizione</strong><p><?= $prod->description ?></p></div>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            <?php } } ?>
            <?php make_toolbar() ?>
        </div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>