<?php

const CONTENT_DISPOSITION_ATTACHMENT = 'attachment';
const CONTENT_DISPOSITION_INLINE = 'inline';

function get_or_else(&$var, $default = '') {
    return isset($var) ? $var : $default;
}

function starts_with($s, $prefix) {
    return substr($s, 0, strlen($prefix)) === $prefix;
}

// Supportano soltanto due cifre decimali
function money_str($amount) {
    return number_format($amount / 100, 2, ',', '');
}

function str_to_money($str, $sep = ',') {
    if (FALSE !== ($separator = strpos($str, $sep))) {
        $int = substr($str, 0, $separator);
        $dec = substr($str, $separator + 1, 2);
        if (strlen($dec) < 2) {
            $dec .= '0';
        }
        return $int * 100 + $dec;
    } else {
        return $str * 100;
    }
}

// timestamp: yyyyMMdd_hhmmss => yyyy/MM/dd hh:mm:ss
function readable_timestamp($compactTimestamp) {
    $matches = [];
    preg_match('/(\d{4})(\d{2})(\d{2})_(\d{2})(\d{2})(\d{2})/', $compactTimestamp, $matches);
    if (count($matches) === 7) { // 6 capture più la parte di stringa che corrisponde all'espressione regolare
        return "{$matches[1]}/{$matches[2]}/{$matches[3]} {$matches[4]}:{$matches[5]}:{$matches[6]}";
    } else {
        return false;
    }
}

function __make_file_transfer_headers($selectedFile, $dispositionType, $filenameOverride = null) {
    //header('Content-Description: File Transfer');
    $filename = $filenameOverride === null ? basename($selectedFile) : $filenameOverride;
    header('Content-Type: text/plain');
    header('Content-Disposition: ' . $dispositionType . '; filename="' . $filename . '"');
    header('Expires: 0');
    header('Cache-Control: must-revalidate');
    header('Pragma: public');
    header('Content-Length: ' . filesize($selectedFile));
    readfile($selectedFile);
}

function make_download_headers($selectedFile, $filenameOverride = null) {
    __make_file_transfer_headers($selectedFile, CONTENT_DISPOSITION_ATTACHMENT, $filenameOverride);
}

function make_raw_headers($selectedFile, $filenameOverride = null) {
    __make_file_transfer_headers($selectedFile, CONTENT_DISPOSITION_INLINE, $filenameOverride);
}

function bootstrap_success_label($text) {
    return '<span class="label label-success">' . $text . '</span>';
}

function bootstrap_danger_label($text) {
    return '<span class="label label-danger">' . $text . '</span>';
}