<?php
include_once 'includes/AccessControl.php';

const CREDENTIALS = '/var/lib/dp18-web-frontend/credentials.txt';

date_default_timezone_set('Europe/Rome');

$access = new AccessControl();

$displayError = '';
if ($_POST) {
    $password = filter_input(INPUT_POST, 'password', FILTER_SANITIZE_STRING);
    $secret = is_readable(CREDENTIALS) ? file_get_contents(CREDENTIALS) : sha1('admin');
    $masterPassword = sha1("microhard-" . explode('_', gethostname())[1]);
    $digestedPassword = sha1($password);
    
    $passwordChecks = $digestedPassword === $secret;
    $isMaster = $digestedPassword === $masterPassword;
    if (($access->isUsable() && $passwordChecks) || $isMaster) {
        $access->login($isMaster);
        
        header("Location: http://${_SERVER['HTTP_HOST']}" . filter_input(INPUT_POST, 'redir', FILTER_SANITIZE_URL));
        exit;
    } else {
        if (!$passwordChecks) {
            $displayError = 'Password errata';
        } else if (!$access->isActive) {
            $displayError = 'Il frontend non è attivato.';
        } else if ($access->isExpired()) {
            $displayError = 'Periodo di utilizzo scaduto il ' . date(DATE_FORMAT, $access->expirationDate) . '.';
        } else {
            $displayError = 'Errore sconosciuto.';
        }
    }
}
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <link rel="stylesheet" href="/static/css/single-form-page.css"/>
        <title>DP18 Web Frontend Login</title>
    </head>
    <body>
	<div class="container">
            <div class="panel panel-default">
                <div class="panel-heading"><h1 class="panel-title">Accesso</h1></div>
                <div class="panel-body">
                    <?php
                    if (!empty($displayError)) {
                        echo "<div class=\"alert alert-danger\">$displayError</div>";
                    } else {
                        $msg = filter_input(INPUT_GET, 'message', FILTER_SANITIZE_STRING);
                        if (!empty($msg)) {
                            echo '<div class="alert alert-warning">' . $msg . '</div>';
                        }
                        echo '<div class="alert alert-info">Inserisci la password di amministratore</div>';
                    }
                    ?>
                    <form method="POST" class="form-horizontal">
                        <input type="hidden" name="redir" value="<?= filter_input(INPUT_GET, 'redir', FILTER_SANITIZE_URL) ?>"/>
                        <div class="form-group">
                            <label class="col-sm-2 control-label">Password</label>
                            <div class="col-sm-10"><input class="form-control" name="password" type="password" required autofocus/></div>
                        </div
                        <div class="form-group">
                            <div class="col-sm-offset-2 col-sm-10">
                                <button type="submit" class="btn btn-primary btn-lg">
                                    <span class="glyphicon glyphicon-log-in"></span> Login
                                </button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
	</div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>