<?php
require_once 'includes/access.php';
require_once 'includes/util.php';

const ARCHIVE_DIR = '/root/dp18/archive';
const MAX_BODY_LENGTH = 36;

// nella prima riga della mail di solito ho il nome della macchina ed il seriale
// nella seconda riga ho il tipo di evento
// nella terza riga ho il timestamp e la descrizione dell'evento notificato separati da un trattino '-'
// Nel caso del formato vecchio, ho solo una riga
function summarize_object($content) {
    $lines = explode("\n", $content);
    if (count($lines) > 2) { // formato nuovo
        $obj = trim($lines[1]);
        switch ($obj) {
            case 'Alarm': return '<span class="text-danger">Allarme</span>';
            case 'Alarm Clear': return '<span class="text-success">Allarme rientrato</span>';
            default: return '<i>Sconosciuto</i>';
        }
    } else { // formato vecchio
        return '<span class="text-danger">Allarme</span>';
    }
}

function summarize_content($content) {
    $lines = explode("\n", $content);
    if (count($lines) > 2) { // formato nuovo
        $body = trim(explode('-', $lines[2], 2)[1]);
    } else { // formato vecchio
        $body = trim(explode(' ', $lines[0], 3)[2]);
    }
    if (strlen($body) > MAX_BODY_LENGTH) {
        return substr($body, 0, MAX_BODY_LENGTH) . '&hellip;';
    } else {
        return $body;
    }
}

function fullname($basename) {
    return ARCHIVE_DIR . DIRECTORY_SEPARATOR . $basename;
}

$exportFile = filter_input(INPUT_GET, 'export', FILTER_SANITIZE_STRING);
if (!empty($exportFile)) {
    $path = realpath(fullname($exportFile)); // non voglio permettere che si possano scaricare file fuori da /root/sent
    if (pathinfo($path, PATHINFO_DIRNAME) === ARCHIVE_DIR) {
        make_download_headers($path);
        exit;
    }
}

$dateAndFile = [];
foreach (glob(ARCHIVE_DIR . '/*.mail', GLOB_NOSORT) as $filename) {
    $basename = basename($filename);
    $timestamp = readable_timestamp($basename);
    if ($timestamp !== false) {
        $dateAndFile[$timestamp] = $basename;
    } else {
        $dateAndFile[$basename] = $basename;
    }
}
krsort($dateAndFile);
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <script src="/static/js/collapsible-table-rows.js"></script>
        <title>Visualizzazione mail inviate</title>
    </head>
    <body>
        <?php include 'templates/navbar.php' ?>
        <div class="container">
            <div class="page-header">
                <h1>
                    <a title="Torna all'archivio" href="/archive.php"><span class="glyphicon glyphicon-circle-arrow-left"></span></a>
                    Visualizzazione mail inviate
                </h1>
            </div>
            <table class="table table-condensed">
                <thead>
                    <tr><th>Timestamp</th><th>Oggetto</th><th>Contenuto</th><th colspan="2"></th></tr>
                </thead>
                <tbody>
                    <?php
                    $i = 0;
                    foreach ($dateAndFile as $timestamp => $filename) {
                        $content = trim(file_get_contents(fullname($filename)));
                    ?>
                    <tr id="record-<?= $i ?>">
                        <td><?= $timestamp ?></td>
                        <td><?= summarize_object($content) ?></td>
                        <td><?= summarize_content($content) ?></td>
                        <td>
                            <a class="show-content">
                                <span class="glyphicon glyphicon-fullscreen"></span><span class="hidden-xs"> mostra tutto</span>
                            </a>
                        </td>
                        <td>
                            <a title="Esporta" href="?<?= htmlentities(http_build_query(['export' => $filename])) ?>">
                                <span class="glyphicon glyphicon-download"></span><span class="hidden-xs"> Esporta</span>
                            </a>
                        </td>
                    </tr>
                    <tr class="info">
                        <td colspan="5">
                            <pre><?= $content ?></pre>
                        </td>
                    </tr>
                    <?php
                        ++$i;
                    }
                    ?>
                </tbody>
            </table>
        </div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>
