<?php
require_once 'includes/access.php';
require_once 'includes/bootstrap_forms.php';

const SERVICE_NAME = 'dp18';

function class_for_unit_file_state($unitState) {
    switch ($unitState) {
        case 'enabled': return 'text-success';
        default: return 'text-danger';
    }
}

function class_for_state($state) {
    switch ($state) {
        case 'active': return 'text-success';
        case 'activating': return 'text-info';
        default: return 'text-danger';
    }
}

if (isset($_FILES['pacman-package'])) {
    $dest = MHDATA_DIR . DIRECTORY_SEPARATOR . $_FILES['pacman-package']['name'];
    move_uploaded_file($_FILES['pacman-package']['tmp_name'], $dest);
    shell_exec("pacman -U --noconfirm --force --noprogressbar $dest");
} else if (isset($_POST['service-start'])) {
    shell_exec('systemctl start ' . SERVICE_NAME);
} else if (isset($_POST['service-restart'])) {
    shell_exec('systemctl restart ' . SERVICE_NAME);
} else if (isset($_POST['service-stop'])) {
    shell_exec('systemctl stop ' . SERVICE_NAME);
} else if (isset($_POST['set-system-datetime'])) {
    $year  = filter_input(INPUT_POST, 'year',  FILTER_VALIDATE_INT, ['options' => ['min_range' => 2000, 'default' => 2015]]);
    $month = filter_input(INPUT_POST, 'month', FILTER_VALIDATE_INT, ['options' => ['min_range' => 1, 'max_range' => 12, 'default' => 1]]);
    $day   = filter_input(INPUT_POST, 'day',   FILTER_VALIDATE_INT, ['options' => ['min_range' => 1, 'max_range' => 31, 'default' => 1]]);
    $hour  = filter_input(INPUT_POST, 'hour',  FILTER_VALIDATE_INT, ['options' => ['min_range' => 0, 'max_range' => 23, 'default' => 0]]);
    $min   = filter_input(INPUT_POST, 'min',   FILTER_VALIDATE_INT, ['options' => ['min_range' => 0, 'max_range' => 59, 'default' => 0]]);
    $sec   = filter_input(INPUT_POST, 'sec',   FILTER_VALIDATE_INT, ['options' => ['min_range' => 0, 'max_range' => 59, 'default' => 0]]);
    
    exec("timedatectl set-time \"$year-$month-$day $hour:$min:$sec\"");
} else if (isset($_POST['system-reboot'])) {
    shell_exec('reboot');
}

// le proprietà non sono ritornate nell'ordine specificato dall'opzione -p; l'ordine è, invece, definito dal comando show.
// Come aiuto alla memoria, l'ordine delle proprietà nell'invocazione sottostante è la stessa di quella di show.
$props = explode("\n", shell_exec('systemctl show -pActiveState,UnitFileState,ActiveEnterTimestamp ' . SERVICE_NAME));
$activeState = trim(explode('=', $props[0])[1]);
$unitState = trim(explode('=', $props[1])[1]);
$activeSince = trim(explode('=', $props[2])[1]);
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <title>Sistema</title>
        <script>
            function getCurrentDateTime() {
                var d = new Date()
                $('input[name=year]').val(d.getFullYear())
                $('input[name=month]').val(d.getMonth() + 1)
                $('input[name=day]').val(d.getDate())
                $('input[name=hour]').val(d.getHours())
                $('input[name=min]').val(d.getMinutes())
                $('input[name=sec]').val(d.getSeconds())
            }
            
            $(function() {
                getCurrentDateTime()
                
                var timePollInterval = setInterval(function() {
                    $.ajax({
                        method: 'GET',
                        url: '/includes/get_system_datetime.php',
                        success: function(data) {
                            var d = new Date(data)
                            $('#current-datetime').text(d.toString())
                        }
                    })
                }, 5000)
            })
        </script>
    </head>
    <body>
        <?php include 'templates/navbar.php' ?>
        <div class="container">
            <div class="page-header"><h1>Sistema</h1></div>
            <!--form class="form-horizontal" action="/config/configuration_actions.php" method="POST" enctype="multipart/form-data">
                <div class="form-group">
                    <label class="col-xs-3 col-sm-4 control-label">Importa configurazione</label>
                    <div class="col-xs-9 col-sm-8">
                        <input type="file" name="configuration-file"/>
                    </div>
                </div>
                <div class="form-group">
                    <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                        <button type="submit" name="apply" class="btn btn-primary"><span class="glyphicon glyphicon-upload"></span> Invia</button>
                    </div>
                </div>
            </form>
            <hr/-->
            <form class="form-horizontal" method="POST" enctype="multipart/form-data">
                <div class="form-group">
                    <label class="col-xs-3 col-sm-4 control-label">Package di aggiornamento</label>
                    <div class="col-xs-9 col-sm-8">
                        <input type="file" name="pacman-package"/>
                    </div>
                </div>
                <div class="form-group">
                    <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                        <button type="submit" class="btn btn-primary"><span class="glyphicon glyphicon-upload"></span> Installa</button>
                    </div>
                </div>
            </form>
            <hr/>
            <form class="form-horizontal" method="POST">
                <div class="form-group">
                    <label class="col-xs-3 col-sm-4 control-label">Servizio DP18</label>
                    <div class="col-xs-9 col-sm-8">
                        <p class="form-control-static">
                            versione: <strong><?= trim(shell_exec('pacman -Q dp18')) ?></strong>
                        </p>
                    </div>
                    <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                        <p class="form-control-static">
                            stato: <strong class="<?= class_for_state($activeState) ?>"><?= $activeState ?></strong> &mdash;
                            abilitazione: <strong class="<?= class_for_unit_file_state($unitState) ?>"><?= $unitState ?></strong>
                            <br/>
                            attivo da: <strong><?= $activeSince ?></strong>
                        </p>
                    </div>
                    <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                        <?php
                        if ($activeState === 'active') {
                        ?>
                            <button type="submit" class="btn btn-warning" name="service-restart">
                                <span class="glyphicon glyphicon-repeat"></span> Riavvia
                            </button>
                            <button type="submit" class="btn btn-danger" name="service-stop">
                                <span class="glyphicon glyphicon-stop"></span> Stop
                            </button>
                        <?php } else if ($activeState === 'activating') { ?>
                            <button type="submit" class="btn btn-danger" name="service-stop">
                                <span class="glyphicon glyphicon-stop"></span> Stop
                            </button>
                        <?php } else { ?>
                            <button type="submit" class="btn btn-success" name="service-start">
                                <span class="glyphicon glyphicon-play"></span> Start
                            </button>
                        <?php } ?>
                    </div>
                </div>
            </form>
            <hr/>
            <form id="datetime-form" class="form-horizontal" method="POST">
                <div class="form-group">
                    <label class="col-xs-3 col-sm-4 control-label">Data e Ora</label>
                    <div class="col-xs-9 col-sm-8">
                        <p id="current-datetime" class="form-control-static">
                            ???
                        </p>
                        <p class="form-control-static">
                            <?php
                            $res = explode("\n", trim(shell_exec('timedatectl status | tail -4')));
                            foreach ($res as $line) {
                                $tokens = explode(':', $line);
                                echo trim($tokens[0]) . ': <strong>' . trim($tokens[1]) . '</strong><br/>';
                            }
                            ?>
                        </p>
                    </div>
                    <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                        <div class="input-group">
                            <?php
                            make_bootstrap_form_input(
                                    ['name' => 'year', 'type' => 'number', 'min' => 0, 'title' => "Anno"],
                                    ['addon' => 'AA']);
                            make_bootstrap_form_input(
                                    ['name' => 'month', 'type' => 'number', 'min' => 1, 'max' => 12, 'title' => 'Mese'],
                                    ['addon' => 'MM']);
                            make_bootstrap_form_input(
                                    ['name' => 'day', 'type' => 'number', 'min' => 1, 'max' => 31, 'title' => 'Giorno'],
                                    ['addon' => 'gg']);
                            ?>
                        </div>
                    </div>
                </div>
                <div class="form-group">
                    <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                        <div class="input-group">
                            <?php
                            make_bootstrap_form_input(
                                    ['name' => 'hour', 'type' => 'number', 'min' => 0, 'max' => 23, 'title' => 'Ore'],
                                    ['addon' => 'hh']);
                            make_bootstrap_form_input(
                                    ['name' => 'min', 'type' => 'number', 'min' => 0, 'max' => 59, 'title' => 'Minuti'],
                                    ['addon' => 'mm']);
                            make_bootstrap_form_input(
                                    ['name' => 'sec', 'type' => 'number', 'min' => 0, 'max' => 59, 'title' => 'Secondi'],
                                    ['addon' => 'ss'])
                            ?>
                        </div>
                    </div>
                </div>
                <div class="form-group">
                    <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                        <button type="submit" class="btn btn-primary" name="set-system-datetime">
                            <span class="glyphicon glyphicon-ok-sign"></span> Imposta data e ora
                        </button>
                        <button type="button" class="btn btn-default" onclick="getCurrentDateTime()">
                            <span class="glyphicon glyphicon-time"></span> Ora locale
                        </button>
                    </div>
                </div>
            </form>
            <form class="form-horizontal" method="POST">
                <div class="form-group">
                    <label class="col-xs-3 col-sm-4 control-label">Raspberry Pi</label>
                    <div class="col-xs-9 col-sm-8">
                        <p class="form-control-static">
                            <?= php_uname() ?>
                            <br/>
                            acceso da: <strong><?= trim(shell_exec('uptime -s')) ?></strong>
                        </p>
                    </div>
                    <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                        <button type="submit" class="btn btn-danger" name="system-reboot">
                            <span class="glyphicon glyphicon-warning-sign"></span> Reboot
                        </button>
                    </div>
                </div>
            </form>
        </div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>
