<?php
require_once 'includes/access.php';
require_once 'includes/util.php';
require_once 'includes/products.php';
require_once 'includes/workspace.php';
require_once 'includes/product_images.php';

const MOD_FILE = 'mod.xml';

$products = deserialize_catalogues(USER_CATALOGUE_BASE . '/index.xml');
apply_modifications($products, workspace_get(MOD_FILE));

$queryParamsToForward = htmlentities(http_build_query(['show' => filter_input(INPUT_GET, 'show', FILTER_SANITIZE_STRING)]));

$id = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_STRING);
$isNew = !isset($products[$id]);
$prod = new Product(''); // genero un prodotto 'finto' con tutte le proprietà nulle
if (!$isNew) {
    $prod = $products[$id];
}
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <title></title>
    </head>
    <body>
        <div class="container">
            <h1><?= $isNew ? 'Aggiungi nuovo prodotto' : 'Modifica prodotto ' . $prod->name ?></h1>
            <div class="row">
                <div class="col-xs-4 col-sm-2">
                    <img src="<?= get_thumbnail_url($prod) ?>" class="center-block" style="width: 170px; height: 280px"/>
                </div>
                <form class="form-horizontal col-xs-8 col-sm-10"
                      role="form"
                      method="post"
                      action="includes/edit_user_product.php"
                      enctype="multipart/form-data">
                    <input type="hidden" name="redir" value="/user_products.php?<?= $queryParamsToForward ?>"/>
                    <div class="form-group">
                        <label for="id" class="control-label col-sm-2">ID prodotto</label>
                        <div class="col-sm-10">
                            <?php if ($isNew) { ?>
                                <input type="text"
                                       pattern="[\w\-]+"
                                       title="Identificatore composto da caratteri alfanumerici, trattini o sottolineature '_'"
                                       class="form-control"
                                       name="id"
                                       required
                                       id="id"/>
                            <?php } else { ?>
                                <input type="text" class="form-control" required readonly id="id" value="<?= $prod->product_id() ?>"/>
                                <input type="hidden" name="id" value="<?= $prod->full_id ?>"/>
                            <?php } ?>
                        </div>
                    </div>
                    <?php
                    if ($prod->isDeleted()) {
                    ?>
                        <div class="form-group">
                            <label class="control-label col-sm-2">Nome</label>
                            <div class="col-sm-10"><input type="text" class="form-control" readonly value="<?= $prod->name ?>"/></div>
                        </div>
                        <div class="form-group">
                            <div class="alert alert-warning">
                                Il prodotto è stato rimosso
                            </div>
                        </div>
                    <?php } else { ?>
                        <div class="form-group">
                            <label for="name" class="control-label col-sm-2">Nome</label>
                            <div class="col-sm-10">
                                <input type="text"
                                       class="form-control col-sm-10"
                                       name="name"
                                       value="<?= $prod->name ?>"
                                       id="name" required/>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="category" class="control-label col-sm-2">Categoria</label>
                            <div class="col-sm-10">
                                <input type="text"
                                       class="form-control"
                                       name="category"
                                       value="<?= $prod->category ?>"
                                       id="category" required/>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="full-price" class="control-label col-sm-2">Prezzo intero</label>
                            <div class="col-sm-10">
                                <div class="input-group">
                                    <input type="text"
                                           pattern="(0|[1-9]\d*)(,\d{1,2})?"
                                           title="Inserisci un prezzo valido separando i centesimi con la virgola"
                                           class="form-control"
                                           name="prices[0]"
                                           value="<?= money_str($prod->prices[0]) ?>"
                                           id="full-price"/>
                                    <span class="input-group-addon"><span class="glyphicon glyphicon-eur"></span></span>
                                </div>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="discounted-price" class="control-label col-sm-2">Prezzo scontato</label>
                            <div class="col-sm-10">
                                <div class="input-group">
                                    <input type="text"
                                           pattern="(0|[1-9]\d*)(,\d{1,2})?"
                                           title="Inserisci un prezzo valido separando i centesimi con la virgola"
                                           class="form-control col-sm-10"
                                           name="prices[1]"
                                           value="<?= money_str($prod->prices[1]) ?>"
                                           id="discounted-price"/>
                                    <span class="input-group-addon"><span class="glyphicon glyphicon-eur"></span></span>
                                </div>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="description" class="control-label col-sm-2">Descrizione</label>
                            <div class="col-sm-10"><textarea name="description" class="form-control col-sm-10" cols="24" rows="6" id="description"><?= $prod->description ?></textarea></div>
                        </div>
                        <div class="form-group">
                            <label for="thumbnail" class="control-label col-sm-2">Miniatura</label>
                            <div class="form-control-static">
                                <?= product_has_thumbnail($prod) ? bootstrap_success_label('Sì') : bootstrap_danger_label('No') ?>
                            </div>
                            <div class="col-xs-offset-2">
                                <input type="file" name="thumbnail"/>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="image" class="control-label col-sm-2">Immagine</label>
                            <div class="form-control-static">
                                <?= product_has_image($prod) ? bootstrap_success_label('Sì') : bootstrap_danger_label('No') ?>
                            </div>
                            <div class="col-xs-offset-2">
                                <input type="file" name="image"/>
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-sm-offset-2 col-sm-10">
                                <a
                                    class="btn btn-default"
                                    href="/user_products.php?<?= $queryParamsToForward ?>">
                                    <span class="glyphicon glyphicon-chevron-left"></span> Annulla
                                </a>
                                <?php if ($isNew) { ?>
                                    <button type="submit" class="btn btn-default" name="put">
                                        <span class="glyphicon glyphicon-plus"></span> Aggiungi
                                    </button>
                                <?php } else { ?>
                                    <button type="submit" class="btn btn-default" name="put">
                                        <span class="glyphicon glyphicon-pencil"></span> Modifica
                                    </button>
                                <?php } ?>
                            </div>
                        </div>
                    <?php } ?>
                </form>
            </div>
        </div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>
